@@ -1,4 +1,5 @@
 import json
+from .label import Label
 from enum import IntEnum
 from .utils import assert_enum_value_in_dict, assert_non_empty_string_in_dict
 
@@ -18,6 +19,7 @@ class FindingType(IntEnum):
     Suspicious = 2
     Degraded = 3
     Info = 4
+    Scam = 5
 
 
 class Finding:
@@ -35,8 +37,11 @@ class Finding:
         self.type = dict['type']
         self.metadata = dict.get('metadata')
         self.addresses = dict.get('addresses')
-        self.labels = dict.get('labels')
+        self.labels = list(map(lambda l: l if isinstance(l, Label) else Label(l), dict.get('labels', [])))
 
     def toJson(self):
-        d = dict(self.__dict__, **{'alertId': self.alert_id})
+        d = dict(self.__dict__, **{
+            'alertId': self.alert_id,
+            'labels': list(map(lambda l: l.toDict(), self.labels))
+        })
         return json.dumps({k: v for k, v in d.items() if v or k == 'type' or k == 'severity'})
